evdiag computes, returns, and visualizes the eigenvalues of crossprod(facload).
This can be used as a rough guide to choose the numbers of factors in a model.
evdiag(x)Invisibly returns a matrix with posterior samples of the eigenvalues of crossprod(facload)
Object of class 'fsvdraws', usually resulting from a call
to fsvsample.
Other plotting:
comtimeplot(),
corimageplot(),
corplot(),
cortimeplot(),
facloadcredplot(),
facloaddensplot(),
facloadpairplot(),
facloadpointplot(),
facloadtraceplot(),
logvartimeplot(),
paratraceplot(),
plot.fsvdraws(),
plotalot(),
voltimeplot()