Draws a collection of plots to explore the posterior distribution of a fitted factor SV model.
plotalot(x, fsvsimobj = NULL, ...)Returns x invisibly.
Object of class 'fsvdraws', usually resulting from a call
to fsvsample.
To indicate data generating values in case of simulated
data, pass an object of type fsvsim (usually the result of a
call to fsvsim).
Other arguments will be passed on to the subfunctions.
Other plotting:
comtimeplot(),
corimageplot(),
corplot(),
cortimeplot(),
evdiag(),
facloadcredplot(),
facloaddensplot(),
facloadpairplot(),
facloadpointplot(),
facloadtraceplot(),
logvartimeplot(),
paratraceplot(),
plot.fsvdraws(),
voltimeplot()